==> redquicklib-1.328.0.tgz: package/lib/screens/identitylogin.js <==
import React, { Component } from 'react';
import { connect } from 'react-redux';
import {
    Container,
    Header,
    Content,
    Card,
    CardItem,
    Footer,
    FooterTab,
    Button,
    Icon,
    List,
    ListItem,
    CheckBox,
    InputGroup, Title,
    Text, Picker,
    Spinner,
    Input,
    Left,
    Body,
    Right,
} from 'native-base';

import * as Common from '../common';
import SocialLogin from '../components/reactnativelogin';

import {
    Platform, StyleSheet,
    View,
    Dimensions, Alert
} from 'react-native';

import * as UIA from '../actions/uiActions';
import * as utils from '../util';
import { Colors } from '../colors';
import * as Keys from '../keys';
import * as Titles from '../titles';
import SafariLogin from '../components/safarilogin';
import { Actions } from 'react-native-router-flux';
const { width, height } = Dimensions.get('window');
import * as Globals from '../globals';
const Item = Picker.Item;
class IdentityLogin extends Component {
    constructor(props) {
        super(props);
        this.state = {
            checked: {}
        };
    }

    render() {
        var me = this;
        var { state } = me.props;

        var identityProvider =  me.props.provider;
        var address = `Account/LogoffThenIn/${identityProvider}`;

        var alertfunc = () => Alert.alert(
            Titles.AreYouSure,
            Titles.AreYouSure,
            [
                { text: Titles.Ok, onPress: Actions.pop },
                { text: Titles.Cancel, onPress: () => { } },
            ]
        );
        return (
            <Container>
                <Content>
                    <SocialLogin
                        loginUrl={() => {
                            return Globals.getDefaultURL('/').then(res => {
                                return res + address;
                            });
                        }}
                        ui={(p) => {
                            me.props.UI('URL_', p)
                        }}
                        onAuthentification={(e) => {
                            me.props.loginProcess(e);
                        }}>
                    </SocialLogin>
                    {Common.Banner()}
                    <List>
                        <ListItem><Left><Spinner /><Text>Loading Screen</Text></Left></ListItem>
                    </List>
                </Content>
                <Footer>
                    <FooterTab>
                        <Button onPress={() => {
                            me.props.logout(Actions.login);
                        }}>
                            <Text>{Titles.Cancel}</Text>
                            <Icon name='md-close' />
                        </Button>
                    </FooterTab>
                </Footer>
            </Container>
        );
    }
}


const styles = StyleSheet.create({
    picker: {
        width: 100,
    },
    container: Object.assign({}, StyleSheet.absoluteFillObject, {
        width,
        height,
    }),
    map: Object.assign({}, StyleSheet.absoluteFillObject)
});


export default connect(utils.mapStateToProps, utils.mapDispatchToProps)(IdentityLogin);

==> redquicklib-1.376.0.tgz: package/lib/screens/identitylogin.js <==
import React, { Component } from 'react';
import { connect } from 'react-redux';
import {
    Container,
    Header,
    Content,
    Card,
    CardItem,
    Footer,
    FooterTab,
    Button,
    Icon,
    List,
    ListItem,
    CheckBox,
    InputGroup, Title,
    Text, Picker,
    Spinner,
    Input,
    Left,
    Body,
    Right,
} from 'native-base';

import * as Common from '../common';
import SocialLogin from '../components/reactnativelogin';

import {
    Platform, StyleSheet,
    View,
    Dimensions, Alert
} from 'react-native';

import * as UIA from '../actions/uiActions';
import * as utils from '../util';
import { Colors } from '../colors';
import * as Keys from '../keys';
import * as Titles from '../titles';
import SafariLogin from '../components/safarilogin';
import { Actions } from 'react-native-router-flux';
const { width, height } = Dimensions.get('window');
import * as Globals from '../globals';
const Item = Picker.Item;
class IdentityLogin extends Component {
    constructor(props) {
        super(props);
        this.state = {
            checked: {}
        };
    }

    render() {
        var me = this;
        var { state } = me.props;

        var identityProvider =  me.props.provider;
        var address = `Account/LogoffThenIn/${identityProvider}`;

        var alertfunc = () => Alert.alert(
            Titles.AreYouSure,
            Titles.AreYouSure,
            [
                { text: Titles.Ok, onPress: Actions.pop },
                { text: Titles.Cancel, onPress: () => { } },
            ]
        );
        return (
            <Container>
                <Content>
                    <SocialLogin
                        loginUrl={() => {
                            return Globals.getDefaultURL('/').then(res => {
                                return res + address;
                            });
                        }}
                        ui={(p) => {
                            me.props.UI('URL_', p)
                        }}
                        onAuthentification={(e) => {
                            me.props.loginProcess(e);
                        }}>
                    </SocialLogin>
                    {Common.Banner()}
                    <List>
                        <ListItem><Left><Spinner /><Text>Loading Screen</Text></Left></ListItem>
                    </List>
                </Content>
                <Footer>
                    <FooterTab>
                        <Button onPress={() => {
                            me.props.logout(Actions.Login);
                        }}>
                            <Text>{Titles.Cancel}</Text>
                            <Icon name='md-close' />
                        </Button>
                    </FooterTab>
                </Footer>
            </Container>
        );
    }
}


const styles = StyleSheet.create({
    picker: {
        width: 100,
    },
    container: Object.assign({}, StyleSheet.absoluteFillObject, {
        width,
        height,
    }),
    map: Object.assign({}, StyleSheet.absoluteFillObject)
});


export default connect(utils.mapStateToProps, utils.mapDispatchToProps)(IdentityLogin);
